@@ -35,6 +35,8 @@ from raven.transport.registry import TransportRegistry, default_transports
 
 __all__ = ('Client',)
 
+__excepthook__ = None
+
 PLATFORM_NAME = 'python'
 
 # singleton for the client
@@ -117,7 +119,8 @@ class Client(object):
 
     _registry = TransportRegistry(transports=default_transports)
 
-    def __init__(self, dsn=None, raise_send_errors=False, transport=None, **options):
+    def __init__(self, dsn=None, raise_send_errors=False, transport=None,
+                 install_sys_hook=True, **options):
         global Raven
 
         o = options
@@ -139,7 +142,7 @@ class Client(object):
 
         self.include_paths = set(o.get('include_paths') or [])
         self.exclude_paths = set(o.get('exclude_paths') or [])
-        self.name = six.text_type(o.get('name') or defaults.NAME)
+        self.name = six.text_type(o.get('name') or o.get('machine') or defaults.NAME)
         self.auto_log_stacks = bool(
             o.get('auto_log_stacks') or defaults.AUTO_LOG_STACKS)
         self.capture_locals = bool(
@@ -148,7 +151,7 @@ class Client(object):
             o.get('string_max_length') or defaults.MAX_LENGTH_STRING)
         self.list_max_length = int(
             o.get('list_max_length') or defaults.MAX_LENGTH_LIST)
-        self.site = o.get('site', defaults.SITE)
+        self.site = o.get('site')
         self.include_versions = o.get('include_versions', True)
         self.processors = o.get('processors')
         if self.processors is None:
@@ -163,7 +166,6 @@ class Client(object):
 
         self.module_cache = ModuleProxyCache()
 
-        # servers may be set to a NoneType (for Django)
         if not self.is_enabled():
             self.logger.info(
                 'Raven is not configured (logging is disabled). Please see the'
@@ -174,6 +176,9 @@ class Client(object):
 
         self._context = Context()
 
+        if install_sys_hook:
+            self.install_sys_hook()
+
     def set_dsn(self, dsn=None, transport=None):
         if dsn is None and os.environ.get('SENTRY_DSN'):
             msg = "Configuring Raven from environment variable 'SENTRY_DSN'"
@@ -196,6 +201,17 @@ class Client(object):
 
         self.logger.debug("Configuring Raven for host: {0}".format(self.remote))
 
+    def install_sys_hook(self):
+        global __excepthook__
+
+        if __excepthook__ is None:
+            __excepthook__ = sys.excepthook
+
+        def handle_exception(*exc_info):
+            self.captureException(exc_info=exc_info)
+            __excepthook__(*exc_info)
+        sys.excepthook = handle_exception
+
     @classmethod
     def register_scheme(cls, scheme, transport_class):
         cls._registry.register_scheme(scheme, transport_class)
