@@ -45,11 +45,7 @@ def make_client(client_cls, app, dsn=None):
         transport=transport,
         include_paths=set(app.config.get('SENTRY_INCLUDE_PATHS', [])) | set([app.import_name]),
         exclude_paths=app.config.get('SENTRY_EXCLUDE_PATHS'),
-        servers=app.config.get('SENTRY_SERVERS'),
         name=app.config.get('SENTRY_NAME'),
-        public_key=app.config.get('SENTRY_PUBLIC_KEY'),
-        secret_key=app.config.get('SENTRY_SECRET_KEY'),
-        project=app.config.get('SENTRY_PROJECT'),
         site=app.config.get('SENTRY_SITE_NAME'),
         processors=app.config.get('SENTRY_PROCESSORS'),
         string_max_length=app.config.get('SENTRY_MAX_LENGTH_STRING'),
@@ -241,7 +237,7 @@ class Sentry(object):
 
         if wrap_wsgi is not None:
             self.wrap_wsgi = wrap_wsgi
-        else:
+        elif self.wrap_wsgi is None:
             # Fix https://github.com/getsentry/raven-python/issues/412
             # the gist is that we get errors twice in debug mode if we don't do this
             if app and app.debug:
